package xhttp3.internal.connection;

import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.ProtocolException;
import java.net.UnknownServiceException;
import java.security.cert.CertificateException;
import java.util.Arrays;
import java.util.List;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLProtocolException;
import javax.net.ssl.SSLSocket;
import xhttp3.ConnectionSpec;
import xhttp3.internal.Internal;

public final class ConnectionSpecSelector {
   private final List<ConnectionSpec> connectionSpecs;
   private int nextModeIndex = 0;
   private boolean isFallbackPossible;
   private boolean isFallback;

   public ConnectionSpecSelector(List<ConnectionSpec> connectionSpecs) {
      this.connectionSpecs = connectionSpecs;
   }

   private boolean isFallbackPossible(SSLSocket socket) {
      for(int var2 = this.nextModeIndex; var2 < this.connectionSpecs.size(); ++var2) {
         if (((ConnectionSpec)this.connectionSpecs.get(var2)).isCompatible(socket)) {
            return true;
         }
      }

      return false;
   }

   public ConnectionSpec configureSecureSocket(SSLSocket sslSocket) {
      Object var2 = null;
      int var3 = this.nextModeIndex;
      int var4 = this.connectionSpecs.size();

      ConnectionSpec var5;
      while(true) {
         if (var3 >= var4) {
            var5 = (ConnectionSpec)var2;
            break;
         }

         if ((var5 = (ConnectionSpec)this.connectionSpecs.get(var3)).isCompatible(sslSocket)) {
            this.nextModeIndex = var3 + 1;
            break;
         }

         ++var3;
      }

      if (var5 != null) {
         this.isFallbackPossible = this.isFallbackPossible(sslSocket);
         Internal.instance.apply(var5, sslSocket, this.isFallback);
         return var5;
      } else {
         throw new UnknownServiceException("Unable to find acceptable protocols. isFallback=" + this.isFallback + ", modes=" + this.connectionSpecs + ", supported protocols=" + Arrays.toString(sslSocket.getEnabledProtocols()));
      }
   }

   public boolean connectionFailed(IOException e) {
      this.isFallback = true;
      if (!this.isFallbackPossible) {
         return false;
      } else if (e instanceof ProtocolException) {
         return false;
      } else if (e instanceof InterruptedIOException) {
         return false;
      } else {
         boolean var2;
         if ((var2 = e instanceof SSLHandshakeException) && e.getCause() instanceof CertificateException) {
            return false;
         } else if (e instanceof SSLPeerUnverifiedException) {
            return false;
         } else {
            return var2 || e instanceof SSLProtocolException;
         }
      }
   }
}
